Write a program that prints the text "Hi Python" to the console (stdout).

HINTS
-----

To make a python program, create a new file with a `.py` extension and start
writing Python! Execute your program by running it with the
`python` command. e.g.:

.. sourcecode:: bash

    $ python program.py


You can write to the console in the following way:

.. sourcecode:: python

    print("text")


When you are done, you must run:

.. sourcecode:: bash

    $ {script} verify program.py

to proceed. Your program will be tested, a report will be generated, and the
lesson will be marked 'completed' if you are successful.
